@@ -7,29 +7,26 @@
  * See http://mod-qos.sourceforge.net/ for further
  * details.
  *
- * Copyright (C) 2007-2015 Pascal Buchbinder
+ * Copyright (C) 2017 Pascal Buchbinder
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
  *
- * This program is released under the GPL with the additional
- * exemption that compiling, linking, and/or using OpenSSL is allowed.
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
- * MA 02110-1301, USA.
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  *
  */
 
-static const char revision[] = "$Id: qsfilter2.c,v 1.81 2016/10/07 13:33:38 pbuchbinder Exp $";
+static const char revision[] = "$Id: qsfilter2.c,v 1.83 2017/06/29 05:24:33 pbuchbinder Exp $";
 
 /* system */
 #include <stdio.h>
@@ -409,6 +406,11 @@ static void usage(char *cmd, int man) {
   qs_man_print(man, "     also request lines from previous rule generation steps. It\n");
   qs_man_print(man, "     must also include request lines which cover manually generated\n");
   qs_man_print(man, "     rules.\n");
+  qs_man_print(man, "     You may use the 'qos-path' and 'qos-query' variables to create\n");
+  qs_man_print(man, "     an audit log containing all request data (path and query/body data).\n");
+  qs_man_print(man, "     Example: 'CustomLog audit_log %{qos-path}n%{qos-query}n'.\n");
+  qs_man_print(man, "     See also http://mod-qos.sourceforge.net#qsfiltersample about\n");
+  qs_man_print(man, "     the module settings.\n");
   if(man) printf("\n.TP\n");
   qs_man_print(man, "  -c <path>\n");
   if(man) printf("\n");
@@ -480,13 +482,6 @@ static void usage(char *cmd, int man) {
   qs_man_print(man, "     Enables additional decoding methods. Use the same settings as you have\n");
   qs_man_print(man, "     used for the QS_Decoding directive.\n");
   if(man) printf("\n.TP\n");
-  qs_man_print(man, "  -p\n");
-  if(man) printf("\n");
-  qs_man_print(man, "     Repesents query by pcre only (no literal strings).\n");
-  qs_man_print(man, "     Determines the worst case performance for the generated whitelist\n");
-  qs_man_print(man, "     by applying each rule for each request line (output is real time\n");
-  qs_man_print(man, "     filter duration per request line in milliseconds).\n");
-  if(man) printf("\n.TP\n");
   qs_man_print(man, "  -k <prefix>\n");
   if(man) printf("\n");
   qs_man_print(man, "     Prefix used to generate rule identifiers (QSF by default).\n");
