@@ -2,31 +2,31 @@
 /**
  * Utilities for the quality of service module mod_qos.
  *
- * Log rotation tool.
+ * qsrotate.c: Log rotation tool.
  *
  * See http://mod-qos.sourceforge.net/ for further
  * details.
  *
- * Copyright (C) 2007-2015 Pascal Buchbinder
+ * Copyright (C) 2017 Pascal Buchbinder
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
- * MA 02110-1301, USA.
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  *
  */
 
-static const char revision[] = "$Id: qsrotate.c,v 1.30 2016/10/07 13:33:38 pbuchbinder Exp $";
+static const char revision[] = "$Id: qsrotate.c,v 1.33 2017/06/29 05:24:33 pbuchbinder Exp $";
 
 #include <stdio.h>
 #include <string.h>
@@ -83,7 +83,7 @@ static void usage(char *cmd, int man) {
   if(man) {
     printf(".SH SYNOPSIS\n");
   }
-  qs_man_print(man, "%s%s -o <file> [-s <sec> [-t <hours>]] [-f] [-z] [-g <num>] [-u <name>] [-p]\n", man ? "" : "Usage: ", cmd);
+  qs_man_print(man, "%s%s -o <file> [-s <sec> [-t <hours>]] [-b <bytes>] [-f] [-z] [-g <num>] [-u <name>] [-p]\n", man ? "" : "Usage: ", cmd);
   printf("\n");
   if(man) {
     printf(".SH DESCRIPTION\n");
@@ -113,7 +113,7 @@ static void usage(char *cmd, int man) {
   if(man) printf("\n.TP\n");
   qs_man_print(man, "  -b <bytes>\n");
   if(man) printf("\n");
-  qs_man_print(man, "     File size limitation (default are %ld bytes).\n", m_limit);
+  qs_man_print(man, "     File size limitation (default/max. are %ld bytes, min. are 1048576 bytes).\n", m_limit);
   if(man) printf("\n.TP\n");
   qs_man_print(man, "  -f\n");
   if(man) printf("\n");
@@ -322,6 +322,7 @@ int main(int argc, char **argv) {
   int nRead, nWrite;
   time_t now;
   struct stat st;
+  long sizeLimit = 0;
 
   pthread_attr_t *tha = NULL;
   pthread_t tid;
@@ -361,7 +362,7 @@ int main(int argc, char **argv) {
       } 
     } else if(strcmp(*argv,"-b") == 0) {
       if (--argc >= 1) {
-	m_limit = atoi(*(++argv));
+	sizeLimit = atol(*(++argv));
       } 
     } else if(strcmp(*argv,"-z") == 0) {
       m_compress = 1;
@@ -384,7 +385,11 @@ int main(int argc, char **argv) {
   }
 
   if(m_file_name == NULL) usage(m_cmd, 0);
-  if(m_limit < (1024 * 1024)) usage(m_cmd, 0);
+  if(sizeLimit > 0 && sizeLimit < m_limit && sizeLimit >= (1024 * 1024)) {
+    m_limit = sizeLimit;
+  } else if(sizeLimit < (1024 * 1024)) {
+    m_limit = 1024 * 1024;
+  }
 
   if(stat(m_file_name, &st) == 0) {
     m_counter = st.st_size;
